/*
	debug.h - assertions that preserve global data area

	USAGE...
		#include <debug.h>
		ASSERTFILE;
		...
		ASSERT(foo);

		_Assert() is defined in file debug.c.

	HISTORY...
		1993 Steve Maguire, in "Writing Solid Code" p. 219
		10/93 Removed requirement for separate "ASSERTFILE(__FILE__);" (jrv)
		4/94 Restored ASSERTFILE so stated file isn't always debug.h :-) (jrv)
		3/95 User must add semicolon after ASSERTFILE (jrv)

*/
#ifdef DEBUG
	void _Assert(char *, unsigned);
	/* This way we have one copy of this string per file, instead
           of one per assertion */
	#define ASSERTFILE static char strSourceFile[]=__FILE__

	#define ASSERT(claim)					\
		if(claim)					\
			(void)0;				\
		else                /* avoid dangling 'else' */	\
			_Assert(strSourceFile,__LINE__)   
     			/* user supplies final ';' */
#else
	#define ASSERT(claim)   (void)0
	#define ASSERTFILE
#endif
